@@ -26,6 +26,16 @@ def ret_date(elem):
 		})
 	return ret
 
+def ret_formula(elem):
+	ret = build_ret(elem)
+	if elem['formula'] != None:
+		ret.update({
+			'content' : True
+			'type' : 'number'
+			'number' : elem['formula']['number']
+		})
+	return ret
+
 def ret_rich_text(elem):
 	ret = build_ret(elem)
 	if elem['rich_text'] != []:
@@ -174,5 +184,6 @@ def get_properties():
 		"created_by" : ret_created_by,
 		"last_edited_time" : ret_last_edited_time,
 		"last_edited_by" : ret_last_edited_by
+		"formula" : ret_formula
 	}
 	return ret
